import pytest

from fhirmodels.R4.Annotation import Annotation
from fhirmodels.R4.CodeableConcept import CodeableConcept
from fhirmodels.R4.Condition import Condition, Evidence, Stage
from fhirmodels.R4.Identifier import Identifier
from fhirmodels.R4.Meta import Meta
from fhirmodels.R4.Narrative import Narrative
from fhirmodels.R4.Reference import Reference

# Sample data to be used in tests
sample_condition_dict = {
    "resourceType": "Condition",
    "id": "example",
    "meta": {"versionId": "1", "lastUpdated": "2021-05-25T12:30:50.150+00:00"},
    "text": {"status": "generated", "div": "<div>Condition Text</div>"},
    "identifier": [{"system": "http://example.org", "value": "12345"}],
    "clinicalStatus": {
        "coding": [
            {
                "system": "http://terminology.hl7.org/CodeSystem/condition-clinical",
                "code": "active",
            }
        ]
    },
    "verificationStatus": {
        "coding": [
            {
                "system": "http://terminology.hl7.org/CodeSystem/condition-ver-status",
                "code": "confirmed",
            }
        ]
    },
    "category": [
        {
            "coding": [
                {
                    "system": "http://terminology.hl7.org/CodeSystem/condition-category",
                    "code": "problem-list-item",
                }
            ]
        }
    ],
    "severity": {
        "coding": [
            {"system": "http://snomed.info/sct", "code": "255604002", "display": "Mild"}
        ]
    },
    "code": {
        "coding": [
            {
                "system": "http://snomed.info/sct",
                "code": "386661006",
                "display": "Fever",
            }
        ]
    },
    "bodySite": [
        {
            "coding": [
                {
                    "system": "http://snomed.info/sct",
                    "code": "38266002",
                    "display": "Entire body",
                }
            ]
        }
    ],
    "subject": {"reference": "Patient/example"},
    "encounter": {"reference": "Encounter/example"},
    "onsetDateTime": "2021-05-25T12:30:50.150+00:00",
    "abatementDateTime": "2021-05-30T12:30:50.150+00:00",
    "recordedDate": "2021-05-25",
    "recorder": {"reference": "Practitioner/example"},
    "asserter": {"reference": "Practitioner/example"},
    "stage": [
        {
            "summary": {
                "coding": [
                    {
                        "system": "http://snomed.info/sct",
                        "code": "261665006",
                        "display": "Stage I",
                    }
                ]
            },
            "assessment": [{"reference": "Observation/example"}],
        }
    ],
    "evidence": [
        {
            "code": {
                "coding": [
                    {
                        "system": "http://snomed.info/sct",
                        "code": "428341000124106",
                        "display": "Suspected diagnosis",
                    }
                ]
            },
            "detail": [{"reference": "Observation/example"}],
        }
    ],
    "note": [
        {
            "authorString": "Dr. Smith",
            "time": "2021-05-25T12:30:50.150+00:00",
            "text": "Patient is doing well.",
        }
    ],
}


# Test conversion from dictionary to Condition object
def test_condition_from_dict():
    condition = Condition.from_dict(sample_condition_dict)
    assert condition.resourceType == "Condition"
    assert condition.id == "example"
    assert isinstance(condition.meta, Meta)
    assert condition.meta.versionId == "1"
    assert isinstance(condition.text, Narrative)
    assert condition.text.div == "<div>Condition Text</div>"
    assert isinstance(condition.identifier[0], Identifier)
    assert condition.identifier[0].value == "12345"
    assert isinstance(condition.clinicalStatus, CodeableConcept)
    assert condition.clinicalStatus.coding[0].code == "active"
    assert isinstance(condition.verificationStatus, CodeableConcept)
    assert condition.verificationStatus.coding[0].code == "confirmed"
    assert isinstance(condition.category[0], CodeableConcept)
    assert condition.category[0].coding[0].code == "problem-list-item"
    assert isinstance(condition.severity, CodeableConcept)
    assert condition.severity.coding[0].code == "255604002"
    assert isinstance(condition.code, CodeableConcept)
    assert condition.code.coding[0].code == "386661006"
    assert isinstance(condition.bodySite[0], CodeableConcept)
    assert condition.bodySite[0].coding[0].code == "38266002"
    assert isinstance(condition.subject, Reference)
    assert condition.subject.reference == "Patient/example"
    assert isinstance(condition.encounter, Reference)
    assert condition.encounter.reference == "Encounter/example"
    assert condition.onsetDateTime == "2021-05-25T12:30:50.150+00:00"
    assert condition.abatementDateTime == "2021-05-30T12:30:50.150+00:00"
    assert condition.recordedDate == "2021-05-25"
    assert isinstance(condition.recorder, Reference)
    assert condition.recorder.reference == "Practitioner/example"
    assert isinstance(condition.asserter, Reference)
    assert condition.asserter.reference == "Practitioner/example"
    assert isinstance(condition.stage[0], Stage)
    assert condition.stage[0].summary.coding[0].code == "261665006"
    assert isinstance(condition.stage[0].assessment[0], Reference)
    assert condition.stage[0].assessment[0].reference == "Observation/example"
    assert isinstance(condition.evidence[0], Evidence)
    assert condition.evidence[0].code.coding[0].code == "428341000124106"
    assert isinstance(condition.evidence[0].detail[0], Reference)
    assert condition.evidence[0].detail[0].reference == "Observation/example"
    assert isinstance(condition.note[0], Annotation)
    assert condition.note[0].authorString == "Dr. Smith"
    assert condition.note[0].time == "2021-05-25T12:30:50.150+00:00"
    assert condition.note[0].text == "Patient is doing well."


# Test conversion from Condition object to dictionary
def test_condition_as_dict():
    condition = Condition.from_dict(sample_condition_dict)
    condition_dict = condition.as_dict()
    assert condition_dict == sample_condition_dict


# Test conversion from an object implementing as_dict() method to Condition object
def test_condition_from_obj():
    class MockConditionObject:
        def as_dict(self):
            return sample_condition_dict

    condition = Condition.from_obj(MockConditionObject())
    assert condition.resourceType == "Condition"
    assert condition.id == "example"
    assert isinstance(condition.meta, Meta)
    assert condition.meta.versionId == "1"
    assert isinstance(condition.text, Narrative)
    assert condition.text.div == "<div>Condition Text</div>"
    assert isinstance(condition.identifier[0], Identifier)
    assert condition.identifier[0].value == "12345"
    assert isinstance(condition.clinicalStatus, CodeableConcept)
    assert condition.clinicalStatus.coding[0].code == "active"
    assert isinstance(condition.verificationStatus, CodeableConcept)
    assert condition.verificationStatus.coding[0].code == "confirmed"
    assert isinstance(condition.category[0], CodeableConcept)
    assert condition.category[0].coding[0].code == "problem-list-item"
    assert isinstance(condition.severity, CodeableConcept)
    assert condition.severity.coding[0].code == "255604002"
    assert isinstance(condition.code, CodeableConcept)
    assert condition.code.coding[0].code == "386661006"
    assert isinstance(condition.bodySite[0], CodeableConcept)
    assert condition.bodySite[0].coding[0].code == "38266002"
    assert isinstance(condition.subject, Reference)
    assert condition.subject.reference == "Patient/example"
    assert isinstance(condition.encounter, Reference)
    assert condition.encounter.reference == "Encounter/example"
    assert condition.onsetDateTime == "2021-05-25T12:30:50.150+00:00"
    assert condition.abatementDateTime == "2021-05-30T12:30:50.150+00:00"
    assert condition.recordedDate == "2021-05-25"
    assert isinstance(condition.recorder, Reference)
    assert condition.recorder.reference == "Practitioner/example"
    assert isinstance(condition.asserter, Reference)
    assert condition.asserter.reference == "Practitioner/example"
    assert isinstance(condition.stage[0], Stage)
    assert condition.stage[0].summary.coding[0].code == "261665006"
    assert isinstance(condition.stage[0].assessment[0], Reference)
    assert condition.stage[0].assessment[0].reference == "Observation/example"
    assert isinstance(condition.evidence[0], Evidence)
    assert condition.evidence[0].code.coding[0].code == "428341000124106"
    assert isinstance(condition.evidence[0].detail[0], Reference)
    assert condition.evidence[0].detail[0].reference == "Observation/example"
    assert isinstance(condition.note[0], Annotation)
    assert condition.note[0].authorString == "Dr. Smith"
    assert condition.note[0].time == "2021-05-25T12:30:50.150+00:00"
    assert condition.note[0].text == "Patient is doing well."


# Test for invalid input to from_obj()
def test_invalid_input_to_from_obj():
    with pytest.raises(ValueError):
        Condition.from_obj("invalid_input")


# Test with missing optional fields
def test_condition_missing_optional_fields():
    minimal_condition_dict = {"resourceType": "Condition", "id": "example"}
    condition = Condition.from_dict(minimal_condition_dict)
    assert condition.resourceType == "Condition"
    assert condition.id == "example"
    assert condition.meta is None
    assert condition.text is None
    assert condition.identifier == []
    assert condition.clinicalStatus is None
    assert condition.verificationStatus is None
    assert condition.category == []
    assert condition.severity is None
    assert condition.code is None
    assert condition.bodySite == []
    assert condition.subject is None
    assert condition.encounter is None
    assert condition.onsetDateTime is None
    assert condition.abatementDateTime is None
    assert condition.recordedDate is None
    assert condition.recorder is None
    assert condition.asserter is None
    assert condition.stage == []
    assert condition.evidence == []
    assert condition.note == []


if __name__ == "__main__":
    pytest.main()



"""
Generated class for Group. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Period import *
from fhirmodels.R4.Quantity import *
from fhirmodels.R4.Range import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class Characteristic(FhirBaseModel):
    """Identifies traits whose presence r absence is shared by members of the group.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: Kind of characteristic
    :param CodeableConcept valueCodeableConcept: Value held by characteristic
    :param bool valueBoolean: Value held by characteristic
    :param Quantity valueQuantity: Value held by characteristic
    :param Range valueRange: Value held by characteristic
    :param Reference valueReference: Value held by characteristic
    :param bool exclude: Group includes or excludes
    :param Period period: Period over which characteristic is tested
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueRange": {"class_name": "Range", "is_contained": False},
        "valueReference": {"class_name": "Reference", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueBoolean: "bool" = None,
        valueQuantity: "Quantity" = None,
        valueRange: "Range" = None,
        valueReference: "Reference" = None,
        exclude: "bool" = None,
        period: "Period" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.valueCodeableConcept = valueCodeableConcept
        self.valueBoolean = valueBoolean
        self.valueQuantity = valueQuantity
        self.valueRange = valueRange
        self.valueReference = valueReference
        self.exclude = exclude
        self.period = period

    @classmethod
    def from_dict(cls, data: dict) -> "Group":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Group":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Member(FhirBaseModel):
    """Identifies the resource instances that are members of the group.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference entity: Reference to the group member
    :param Period period: Period member belonged to the group
    :param bool inactive: If member is no longer in group
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "entity": {"class_name": "Reference", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        entity: "Reference" = None,
        period: "Period" = None,
        inactive: "bool" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.entity = entity
        self.period = period
        self.inactive = inactive

    @classmethod
    def from_dict(cls, data: dict) -> "Group":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Group":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Group(DomainResource):
    """Represents a defined collection of entities that may be discussed or acted upon collectively but which are not expected to act collectively, and are not formally or legally recognized; i.e. a collection of entities that isn't an Organization.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Unique id
    :param bool active: Whether this group's record is in active use
    :param str type: person | animal | practitioner | device | medication | substance
    :param bool actual: Descriptive or actual
    :param CodeableConcept code: Kind of Group members
    :param str name: Label for Group
    :param int quantity: Number of members
    :param Reference managingEntity: Entity that is the custodian of the Group's definition
    :param Characteristic characteristic: Include / Exclude group members by Trait
    :param Member member: Who or what is in group
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "managingEntity": {"class_name": "Reference", "is_contained": False},
        "characteristic": {"class_name": "Characteristic", "is_contained": True},
        "member": {"class_name": "Member", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        active: "bool" = None,
        type: "str" = None,
        actual: "bool" = None,
        code: "CodeableConcept" = None,
        name: "str" = None,
        quantity: "int" = None,
        managingEntity: "Reference" = None,
        characteristic: list["Characteristic"] = None,
        member: list["Member"] = None,
    ):

        self.resourceType = "Group"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.active = active
        self.type = type
        self.actual = actual
        self.code = code
        self.name = name
        self.quantity = quantity
        self.managingEntity = managingEntity
        self.characteristic = characteristic or []
        self.member = member or []

    @classmethod
    def from_dict(cls, data: dict) -> "Group":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Group":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for CodeableConcept. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4.Coding import *
from fhirmodels.R4.Extension import *


class CodeableConcept(FhirBaseModel):
    """Base StructureDefinition for CodeableConcept Type: A concept that may be defined by a formal reference to a terminology or ontology or may be provided by text.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Coding coding: Code defined by a terminology system
    :param str text: Plain text representation of the concept
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "coding": {"class_name": "Coding", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        coding: list["Coding"] = None,
        text: "str" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.coding = coding or []
        self.text = text

    @classmethod
    def from_dict(cls, data: dict) -> "CodeableConcept":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CodeableConcept":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for VisionPrescription. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Annotation import *
from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class Prism(FhirBaseModel):
    """Allows for adjustment on two axis.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param float amount: Amount of adjustment
    :param str base: up | down | in | out
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        amount: "float" = None,
        base: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.amount = amount
        self.base = base

    @classmethod
    def from_dict(cls, data: dict) -> "VisionPrescription":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "VisionPrescription":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class LensSpecification(FhirBaseModel):
    """Contain the details of  the individual lens specifications and serves as the authorization for the fullfillment by certified professionals.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept product: Product to be supplied
    :param str eye: right | left
    :param float sphere: Power of the lens
    :param float cylinder: Lens power for astigmatism
    :param int axis: Lens meridian which contain no power for astigmatism
    :param Prism prism: Eye alignment compensation
    :param float add: Added power for multifocal levels
    :param float power: Contact lens power
    :param float backCurve: Contact lens back curvature
    :param float diameter: Contact lens diameter
    :param Quantity duration: Lens wear duration
    :param str color: Color required
    :param str brand: Brand required
    :param Annotation note: Notes for coatings
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "product": {"class_name": "CodeableConcept", "is_contained": False},
        "prism": {"class_name": "Prism", "is_contained": True},
        "duration": {"class_name": "Quantity", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        product: "CodeableConcept" = None,
        eye: "str" = None,
        sphere: "float" = None,
        cylinder: "float" = None,
        axis: "int" = None,
        prism: list["Prism"] = None,
        add: "float" = None,
        power: "float" = None,
        backCurve: "float" = None,
        diameter: "float" = None,
        duration: "Quantity" = None,
        color: "str" = None,
        brand: "str" = None,
        note: list["Annotation"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.product = product
        self.eye = eye
        self.sphere = sphere
        self.cylinder = cylinder
        self.axis = axis
        self.prism = prism or []
        self.add = add
        self.power = power
        self.backCurve = backCurve
        self.diameter = diameter
        self.duration = duration
        self.color = color
        self.brand = brand
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "VisionPrescription":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "VisionPrescription":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class VisionPrescription(DomainResource):
    """An authorization for the provision of glasses and/or contact lenses to a patient.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business Identifier for vision prescription
    :param str status: active | cancelled | draft | entered-in-error
    :param str created: Response creation date
    :param Reference patient: Who prescription is for
    :param Reference encounter: Created during encounter / admission / stay
    :param str dateWritten: When prescription was authorized
    :param Reference prescriber: Who authorized the vision prescription
    :param LensSpecification lensSpecification: Vision lens authorization
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "patient": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "prescriber": {"class_name": "Reference", "is_contained": False},
        "lensSpecification": {"class_name": "LensSpecification", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        created: "str" = None,
        patient: "Reference" = None,
        encounter: "Reference" = None,
        dateWritten: "str" = None,
        prescriber: "Reference" = None,
        lensSpecification: list["LensSpecification"] = None,
    ):

        self.resourceType = "VisionPrescription"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.created = created
        self.patient = patient
        self.encounter = encounter
        self.dateWritten = dateWritten
        self.prescriber = prescriber
        self.lensSpecification = lensSpecification or []

    @classmethod
    def from_dict(cls, data: dict) -> "VisionPrescription":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "VisionPrescription":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for SearchParameter. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.ContactDetail import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Resource import *
from fhirmodels.R4B.UsageContext import *


class Component(FhirBaseModel):
    """Used to define the parts of a composite search parameter.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str definition: Defines how the part works
    :param str expression: Subexpression relative to main expression
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        definition: "str" = None,
        expression: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.definition = definition
        self.expression = expression

    @classmethod
    def from_dict(cls, data: dict) -> "SearchParameter":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SearchParameter":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SearchParameter(DomainResource):
    """A search parameter that defines a named search item that can be used to search/filter on a resource.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this search parameter, represented as a URI (globally unique)
    :param str version: Business version of the search parameter
    :param str name: Name for this search parameter (computer friendly)
    :param str derivedFrom: Original definition for the search parameter
    :param str status: draft | active | retired | unknown
    :param bool experimental: For testing purposes, not real usage
    :param str date: Date last changed
    :param str publisher: Name of the publisher (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the search parameter
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for search parameter (if applicable)
    :param str purpose: Why this search parameter is defined
    :param str code: Code used in URL
    :param str base: The resource type(s) this search parameter applies to
    :param str type: number | date | string | token | reference | composite | quantity | uri | special
    :param str expression: FHIRPath expression that extracts the values
    :param str xpath: XPath that extracts the values
    :param str xpathUsage: normal | phonetic | nearby | distance | other
    :param str target: Types of resource (if a resource reference)
    :param bool multipleOr: Allow multiple values per parameter (or)
    :param bool multipleAnd: Allow multiple parameters (and)
    :param str comparator: eq | ne | gt | lt | ge | le | sa | eb | ap
    :param str modifier: missing | exact | contains | not | text | in | not-in | below | above | type | identifier | ofType
    :param str chain: Chained names supported
    :param Component component: For Composite resources to define the parts
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "component": {"class_name": "Component", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        version: "str" = None,
        name: "str" = None,
        derivedFrom: "str" = None,
        status: "str" = None,
        experimental: "bool" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        purpose: "str" = None,
        code: "str" = None,
        base: list["str"] = None,
        type: "str" = None,
        expression: "str" = None,
        xpath: "str" = None,
        xpathUsage: "str" = None,
        target: list["str"] = None,
        multipleOr: "bool" = None,
        multipleAnd: "bool" = None,
        comparator: list["str"] = None,
        modifier: list["str"] = None,
        chain: list["str"] = None,
        component: list["Component"] = None,
    ):

        self.resourceType = "SearchParameter"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.version = version
        self.name = name
        self.derivedFrom = derivedFrom
        self.status = status
        self.experimental = experimental
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.purpose = purpose
        self.code = code
        self.base = base or []
        self.type = type
        self.expression = expression
        self.xpath = xpath
        self.xpathUsage = xpathUsage
        self.target = target or []
        self.multipleOr = multipleOr
        self.multipleAnd = multipleAnd
        self.comparator = comparator or []
        self.modifier = modifier or []
        self.chain = chain or []
        self.component = component or []

    @classmethod
    def from_dict(cls, data: dict) -> "SearchParameter":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SearchParameter":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for BackboneElement. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R5.Extension import *


class BackboneElement(FhirBaseModel):
    """BackboneElement Type: Base definition for all elements that are defined inside a resource - but not those in a data type.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
    ):

        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []

    @classmethod
    def from_dict(cls, data: dict) -> "BackboneElement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "BackboneElement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MolecularSequence. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class ReferenceSeq(FhirBaseModel):
    """A sequence that is used as a reference to describe variants that are present in a sequence analyzed.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept chromosome: Chromosome containing genetic finding
    :param str genomeBuild: The Genome Build used for reference, following GRCh build versions e.g. 'GRCh 37'
    :param str orientation: sense | antisense
    :param CodeableConcept referenceSeqId: Reference identifier
    :param Reference referenceSeqPointer: A pointer to another MolecularSequence entity as reference sequence
    :param str referenceSeqString: A string to represent reference sequence
    :param str strand: watson | crick
    :param int windowStart: Start position of the window on the  reference sequence
    :param int windowEnd: End position of the window on the reference sequence
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "chromosome": {"class_name": "CodeableConcept", "is_contained": False},
        "referenceSeqId": {"class_name": "CodeableConcept", "is_contained": False},
        "referenceSeqPointer": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        chromosome: "CodeableConcept" = None,
        genomeBuild: "str" = None,
        orientation: "str" = None,
        referenceSeqId: "CodeableConcept" = None,
        referenceSeqPointer: "Reference" = None,
        referenceSeqString: "str" = None,
        strand: "str" = None,
        windowStart: "int" = None,
        windowEnd: "int" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.chromosome = chromosome
        self.genomeBuild = genomeBuild
        self.orientation = orientation
        self.referenceSeqId = referenceSeqId
        self.referenceSeqPointer = referenceSeqPointer
        self.referenceSeqString = referenceSeqString
        self.strand = strand
        self.windowStart = windowStart
        self.windowEnd = windowEnd

    @classmethod
    def from_dict(cls, data: dict) -> "MolecularSequence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MolecularSequence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Variant(FhirBaseModel):
    """The definition of variant here originates from Sequence ontology ([variant_of](http://www.sequenceontology.org/browser/current_svn/term/variant_of)). This element can represent amino acid or nucleic sequence change(including insertion,deletion,SNP,etc.)  It can represent some complex mutation or segment variation with the assist of CIGAR string.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int start: Start position of the variant on the  reference sequence
    :param int end: End position of the variant on the reference sequence
    :param str observedAllele: Allele that was observed
    :param str referenceAllele: Allele in the reference sequence
    :param str cigar: Extended CIGAR string for aligning the sequence with reference bases
    :param Reference variantPointer: Pointer to observed variant information
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "variantPointer": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        start: "int" = None,
        end: "int" = None,
        observedAllele: "str" = None,
        referenceAllele: "str" = None,
        cigar: "str" = None,
        variantPointer: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.start = start
        self.end = end
        self.observedAllele = observedAllele
        self.referenceAllele = referenceAllele
        self.cigar = cigar
        self.variantPointer = variantPointer

    @classmethod
    def from_dict(cls, data: dict) -> "MolecularSequence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MolecularSequence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Roc(FhirBaseModel):
    """Receiver Operator Characteristic (ROC) Curve  to give sensitivity/specificity tradeoff.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int score: Genotype quality score
    :param int numTP: Roc score true positive numbers
    :param int numFP: Roc score false positive numbers
    :param int numFN: Roc score false negative numbers
    :param float precision: Precision of the GQ score
    :param float sensitivity: Sensitivity of the GQ score
    :param float fMeasure: FScore of the GQ score
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        score: list["int"] = None,
        numTP: list["int"] = None,
        numFP: list["int"] = None,
        numFN: list["int"] = None,
        precision: list["float"] = None,
        sensitivity: list["float"] = None,
        fMeasure: list["float"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.score = score or []
        self.numTP = numTP or []
        self.numFP = numFP or []
        self.numFN = numFN or []
        self.precision = precision or []
        self.sensitivity = sensitivity or []
        self.fMeasure = fMeasure or []

    @classmethod
    def from_dict(cls, data: dict) -> "MolecularSequence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MolecularSequence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Quality(FhirBaseModel):
    """An experimental feature attribute that defines the quality of the feature in a quantitative way, such as a phred quality score ([SO:0001686](http://www.sequenceontology.org/browser/current_svn/term/SO:0001686)).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str type: indel | snp | unknown
    :param CodeableConcept standardSequence: Standard sequence for comparison
    :param int start: Start position of the sequence
    :param int end: End position of the sequence
    :param Quantity score: Quality score for the comparison
    :param CodeableConcept method: Method to get quality
    :param float truthTP: True positives from the perspective of the truth data
    :param float queryTP: True positives from the perspective of the query data
    :param float truthFN: False negatives
    :param float queryFP: False positives
    :param float gtFP: False positives where the non-REF alleles in the Truth and Query Call Sets match
    :param float precision: Precision of comparison
    :param float recall: Recall of comparison
    :param float fScore: F-score
    :param Roc roc: Receiver Operator Characteristic (ROC) Curve
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "standardSequence": {"class_name": "CodeableConcept", "is_contained": False},
        "score": {"class_name": "Quantity", "is_contained": False},
        "method": {"class_name": "CodeableConcept", "is_contained": False},
        "roc": {"class_name": "Roc", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "str" = None,
        standardSequence: "CodeableConcept" = None,
        start: "int" = None,
        end: "int" = None,
        score: "Quantity" = None,
        method: "CodeableConcept" = None,
        truthTP: "float" = None,
        queryTP: "float" = None,
        truthFN: "float" = None,
        queryFP: "float" = None,
        gtFP: "float" = None,
        precision: "float" = None,
        recall: "float" = None,
        fScore: "float" = None,
        roc: "Roc" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.standardSequence = standardSequence
        self.start = start
        self.end = end
        self.score = score
        self.method = method
        self.truthTP = truthTP
        self.queryTP = queryTP
        self.truthFN = truthFN
        self.queryFP = queryFP
        self.gtFP = gtFP
        self.precision = precision
        self.recall = recall
        self.fScore = fScore
        self.roc = roc

    @classmethod
    def from_dict(cls, data: dict) -> "MolecularSequence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MolecularSequence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Repository(FhirBaseModel):
    """Configurations of the external repository. The repository shall store target's observedSeq or records related with target's observedSeq.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str type: directlink | openapi | login | oauth | other
    :param str url: URI of the repository
    :param str name: Repository's name
    :param str datasetId: Id of the dataset that used to call for dataset in repository
    :param str variantsetId: Id of the variantset that used to call for variantset in repository
    :param str readsetId: Id of the read
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "str" = None,
        url: "str" = None,
        name: "str" = None,
        datasetId: "str" = None,
        variantsetId: "str" = None,
        readsetId: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.url = url
        self.name = name
        self.datasetId = datasetId
        self.variantsetId = variantsetId
        self.readsetId = readsetId

    @classmethod
    def from_dict(cls, data: dict) -> "MolecularSequence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MolecularSequence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Outer(FhirBaseModel):
    """Structural variant outer.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int start: Structural variant outer start
    :param int end: Structural variant outer end
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        start: "int" = None,
        end: "int" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.start = start
        self.end = end

    @classmethod
    def from_dict(cls, data: dict) -> "MolecularSequence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MolecularSequence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Inner(FhirBaseModel):
    """Structural variant inner.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int start: Structural variant inner start
    :param int end: Structural variant inner end
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        start: "int" = None,
        end: "int" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.start = start
        self.end = end

    @classmethod
    def from_dict(cls, data: dict) -> "MolecularSequence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MolecularSequence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class StructureVariant(FhirBaseModel):
    """Information about chromosome structure variation.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept variantType: Structural variant change type
    :param bool exact: Does the structural variant have base pair resolution breakpoints?
    :param int length: Structural variant length
    :param Outer outer: Structural variant outer
    :param Inner inner: Structural variant inner
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "variantType": {"class_name": "CodeableConcept", "is_contained": False},
        "outer": {"class_name": "Outer", "is_contained": True},
        "inner": {"class_name": "Inner", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        variantType: "CodeableConcept" = None,
        exact: "bool" = None,
        length: "int" = None,
        outer: "Outer" = None,
        inner: "Inner" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.variantType = variantType
        self.exact = exact
        self.length = length
        self.outer = outer
        self.inner = inner

    @classmethod
    def from_dict(cls, data: dict) -> "MolecularSequence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MolecularSequence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MolecularSequence(DomainResource):
    """Raw data describing a biological sequence.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Unique ID for this particular sequence. This is a FHIR-defined id
    :param str type: aa | dna | rna
    :param int coordinateSystem: Base number of coordinate system (0 for 0-based numbering or coordinates, inclusive start, exclusive end, 1 for 1-based numbering, inclusive start, inclusive end)
    :param Reference patient: Who and/or what this is about
    :param Reference specimen: Specimen used for sequencing
    :param Reference device: The method for sequencing
    :param Reference performer: Who should be responsible for test result
    :param Quantity quantity: The number of copies of the sequence of interest.  (RNASeq)
    :param ReferenceSeq referenceSeq: A sequence used as reference
    :param Variant variant: Variant in sequence
    :param str observedSeq: Sequence that was observed
    :param Quality quality: An set of value as quality of sequence
    :param int readCoverage: Average number of reads representing a given nucleotide in the reconstructed sequence
    :param Repository repository: External repository which contains detailed report related with observedSeq in this resource
    :param Reference pointer: Pointer to next atomic sequence
    :param StructureVariant structureVariant: Structural variant
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "patient": {"class_name": "Reference", "is_contained": False},
        "specimen": {"class_name": "Reference", "is_contained": False},
        "device": {"class_name": "Reference", "is_contained": False},
        "performer": {"class_name": "Reference", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "referenceSeq": {"class_name": "ReferenceSeq", "is_contained": True},
        "variant": {"class_name": "Variant", "is_contained": True},
        "quality": {"class_name": "Quality", "is_contained": True},
        "repository": {"class_name": "Repository", "is_contained": True},
        "pointer": {"class_name": "Reference", "is_contained": False},
        "structureVariant": {"class_name": "StructureVariant", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        type: "str" = None,
        coordinateSystem: "int" = None,
        patient: "Reference" = None,
        specimen: "Reference" = None,
        device: "Reference" = None,
        performer: "Reference" = None,
        quantity: "Quantity" = None,
        referenceSeq: "ReferenceSeq" = None,
        variant: list["Variant"] = None,
        observedSeq: "str" = None,
        quality: list["Quality"] = None,
        readCoverage: "int" = None,
        repository: list["Repository"] = None,
        pointer: list["Reference"] = None,
        structureVariant: list["StructureVariant"] = None,
    ):

        self.resourceType = "MolecularSequence"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.type = type
        self.coordinateSystem = coordinateSystem
        self.patient = patient
        self.specimen = specimen
        self.device = device
        self.performer = performer
        self.quantity = quantity
        self.referenceSeq = referenceSeq
        self.variant = variant or []
        self.observedSeq = observedSeq
        self.quality = quality or []
        self.readCoverage = readCoverage
        self.repository = repository or []
        self.pointer = pointer or []
        self.structureVariant = structureVariant or []

    @classmethod
    def from_dict(cls, data: dict) -> "MolecularSequence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MolecularSequence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ImmunizationEvaluation. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class ImmunizationEvaluation(DomainResource):
    """Describes a comparison of an immunization event against published recommendations to determine if the administration is "valid" in relation to those  recommendations.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business identifier
    :param str status: completed | entered-in-error
    :param Reference patient: Who this evaluation is for
    :param str date: Date evaluation was performed
    :param Reference authority: Who is responsible for publishing the recommendations
    :param CodeableConcept targetDisease: Evaluation target disease
    :param Reference immunizationEvent: Immunization being evaluated
    :param CodeableConcept doseStatus: Status of the dose relative to published recommendations
    :param CodeableConcept doseStatusReason: Reason for the dose status
    :param str description: Evaluation notes
    :param str series: Name of vaccine series
    :param int doseNumberPositiveInt: Dose number within series
    :param str doseNumberString: Dose number within series
    :param int seriesDosesPositiveInt: Recommended number of doses for immunity
    :param str seriesDosesString: Recommended number of doses for immunity
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "patient": {"class_name": "Reference", "is_contained": False},
        "authority": {"class_name": "Reference", "is_contained": False},
        "targetDisease": {"class_name": "CodeableConcept", "is_contained": False},
        "immunizationEvent": {"class_name": "Reference", "is_contained": False},
        "doseStatus": {"class_name": "CodeableConcept", "is_contained": False},
        "doseStatusReason": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        patient: "Reference" = None,
        date: "str" = None,
        authority: "Reference" = None,
        targetDisease: "CodeableConcept" = None,
        immunizationEvent: "Reference" = None,
        doseStatus: "CodeableConcept" = None,
        doseStatusReason: list["CodeableConcept"] = None,
        description: "str" = None,
        series: "str" = None,
        doseNumberPositiveInt: "int" = None,
        doseNumberString: "str" = None,
        seriesDosesPositiveInt: "int" = None,
        seriesDosesString: "str" = None,
    ):

        self.resourceType = "ImmunizationEvaluation"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.patient = patient
        self.date = date
        self.authority = authority
        self.targetDisease = targetDisease
        self.immunizationEvent = immunizationEvent
        self.doseStatus = doseStatus
        self.doseStatusReason = doseStatusReason or []
        self.description = description
        self.series = series
        self.doseNumberPositiveInt = doseNumberPositiveInt
        self.doseNumberString = doseNumberString
        self.seriesDosesPositiveInt = seriesDosesPositiveInt
        self.seriesDosesString = seriesDosesString

    @classmethod
    def from_dict(cls, data: dict) -> "ImmunizationEvaluation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImmunizationEvaluation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for SubstanceNucleicAcid. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Attachment import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Resource import *


class Linkage(FhirBaseModel):
    """The linkages between sugar residues will also be captured.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str connectivity: The entity that links the sugar residues together should also be captured for nearly all naturally occurring nucleic acid the linkage is a phosphate group. For many synthetic oligonucleotides phosphorothioate linkages are often seen. Linkage connectivity is assumed to be 3’-5’. If the linkage is either 3’-3’ or 5’-5’ this should be specified
    :param Identifier identifier: Each linkage will be registered as a fragment and have an ID
    :param str name: Each linkage will be registered as a fragment and have at least one name. A single name shall be assigned to each linkage
    :param str residueSite: Residues shall be captured as described in 5.3.6.8.3
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        connectivity: "str" = None,
        identifier: "Identifier" = None,
        name: "str" = None,
        residueSite: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.connectivity = connectivity
        self.identifier = identifier
        self.name = name
        self.residueSite = residueSite

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceNucleicAcid":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceNucleicAcid":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Sugar(FhirBaseModel):
    """5.3.6.8.1 Sugar ID (Mandatory).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Identifier identifier: The Substance ID of the sugar or sugar-like component that make up the nucleotide
    :param str name: The name of the sugar or sugar-like component that make up the nucleotide
    :param str residueSite: The residues that contain a given sugar will be captured. The order of given residues will be captured in the 5‘-3‘direction consistent with the base sequences listed above
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: "Identifier" = None,
        name: "str" = None,
        residueSite: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier
        self.name = name
        self.residueSite = residueSite

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceNucleicAcid":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceNucleicAcid":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Subunit(FhirBaseModel):
    """Subunits are listed in order of decreasing length; sequences of the same length will be ordered by molecular weight; subunits that have identical sequences will be repeated multiple times.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int subunit: Index of linear sequences of nucleic acids in order of decreasing length. Sequences of the same length will be ordered by molecular weight. Subunits that have identical sequences will be repeated and have sequential subscripts
    :param str sequence: Actual nucleotide sequence notation from 5' to 3' end using standard single letter codes. In addition to the base sequence, sugar and type of phosphate or non-phosphate linkage should also be captured
    :param int length: The length of the sequence shall be captured
    :param Attachment sequenceAttachment: (TBC)
    :param CodeableConcept fivePrime: The nucleotide present at the 5’ terminal shall be specified based on a controlled vocabulary. Since the sequence is represented from the 5' to the 3' end, the 5’ prime nucleotide is the letter at the first position in the sequence. A separate representation would be redundant
    :param CodeableConcept threePrime: The nucleotide present at the 3’ terminal shall be specified based on a controlled vocabulary. Since the sequence is represented from the 5' to the 3' end, the 5’ prime nucleotide is the letter at the last position in the sequence. A separate representation would be redundant
    :param Linkage linkage: The linkages between sugar residues will also be captured
    :param Sugar sugar: 5.3.6.8.1 Sugar ID (Mandatory)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "sequenceAttachment": {"class_name": "Attachment", "is_contained": False},
        "fivePrime": {"class_name": "CodeableConcept", "is_contained": False},
        "threePrime": {"class_name": "CodeableConcept", "is_contained": False},
        "linkage": {"class_name": "Linkage", "is_contained": True},
        "sugar": {"class_name": "Sugar", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        subunit: "int" = None,
        sequence: "str" = None,
        length: "int" = None,
        sequenceAttachment: "Attachment" = None,
        fivePrime: "CodeableConcept" = None,
        threePrime: "CodeableConcept" = None,
        linkage: list["Linkage"] = None,
        sugar: list["Sugar"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.subunit = subunit
        self.sequence = sequence
        self.length = length
        self.sequenceAttachment = sequenceAttachment
        self.fivePrime = fivePrime
        self.threePrime = threePrime
        self.linkage = linkage or []
        self.sugar = sugar or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceNucleicAcid":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceNucleicAcid":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SubstanceNucleicAcid(DomainResource):
    """Nucleic acids are defined by three distinct elements: the base, sugar and linkage. Individual substance/moiety IDs will be created for each of these elements. The nucleotide sequence will be always entered in the 5’-3’ direction.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param CodeableConcept sequenceType: The type of the sequence shall be specified based on a controlled vocabulary
    :param int numberOfSubunits: The number of linear sequences of nucleotides linked through phosphodiester bonds shall be described. Subunits would be strands of nucleic acids that are tightly associated typically through Watson-Crick base pairing. NOTE: If not specified in the reference source, the assumption is that there is 1 subunit
    :param str areaOfHybridisation: The area of hybridisation shall be described if applicable for double stranded RNA or DNA. The number associated with the subunit followed by the number associated to the residue shall be specified in increasing order. The underscore “” shall be used as separator as follows: “Subunitnumber Residue”
    :param CodeableConcept oligoNucleotideType: (TBC)
    :param Subunit subunit: Subunits are listed in order of decreasing length; sequences of the same length will be ordered by molecular weight; subunits that have identical sequences will be repeated multiple times
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "sequenceType": {"class_name": "CodeableConcept", "is_contained": False},
        "oligoNucleotideType": {"class_name": "CodeableConcept", "is_contained": False},
        "subunit": {"class_name": "Subunit", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        sequenceType: "CodeableConcept" = None,
        numberOfSubunits: "int" = None,
        areaOfHybridisation: "str" = None,
        oligoNucleotideType: "CodeableConcept" = None,
        subunit: list["Subunit"] = None,
    ):

        self.resourceType = "SubstanceNucleicAcid"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.sequenceType = sequenceType
        self.numberOfSubunits = numberOfSubunits
        self.areaOfHybridisation = areaOfHybridisation
        self.oligoNucleotideType = oligoNucleotideType
        self.subunit = subunit or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceNucleicAcid":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceNucleicAcid":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for SubstancePolymer. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Attachment import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.Resource import *


class StartingMaterial(FhirBaseModel):
    """The starting materials - monomer(s) used in the synthesis of the polymer.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: The type of substance for this starting material
    :param CodeableConcept category: Substance high level category, e.g. chemical substance
    :param bool isDefining: Used to specify whether the attribute described is a defining element for the unique identification of the polymer
    :param Quantity amount: A percentage
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "amount": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        category: "CodeableConcept" = None,
        isDefining: "bool" = None,
        amount: "Quantity" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.category = category
        self.isDefining = isDefining
        self.amount = amount

    @classmethod
    def from_dict(cls, data: dict) -> "SubstancePolymer":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstancePolymer":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MonomerSet(FhirBaseModel):
    """Todo.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept ratioType: Captures the type of ratio to the entire polymer, e.g. Monomer/Polymer ratio, SRU/Polymer Ratio
    :param StartingMaterial startingMaterial: The starting materials - monomer(s) used in the synthesis of the polymer
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "ratioType": {"class_name": "CodeableConcept", "is_contained": False},
        "startingMaterial": {"class_name": "StartingMaterial", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        ratioType: "CodeableConcept" = None,
        startingMaterial: list["StartingMaterial"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.ratioType = ratioType
        self.startingMaterial = startingMaterial or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstancePolymer":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstancePolymer":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class DegreeOfPolymerisation(FhirBaseModel):
    """Applies to homopolymer and block co-polymers where the degree of polymerisation within a block can be described.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: The type of the degree of polymerisation shall be described, e.g. SRU/Polymer Ratio
    :param int average: An average amount of polymerisation
    :param int low: A low expected limit of the amount
    :param int high: A high expected limit of the amount
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        average: "int" = None,
        low: "int" = None,
        high: "int" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.average = average
        self.low = low
        self.high = high

    @classmethod
    def from_dict(cls, data: dict) -> "SubstancePolymer":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstancePolymer":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class StructuralRepresentation(FhirBaseModel):
    """A graphical structure for this SRU.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: The type of structure (e.g. Full, Partial, Representative)
    :param str representation: The structural representation as text string in a standard format e.g. InChI, SMILES, MOLFILE, CDX, SDF, PDB, mmCIF
    :param CodeableConcept format: The format of the representation e.g. InChI, SMILES, MOLFILE, CDX, SDF, PDB, mmCIF
    :param Attachment attachment: An attached file with the structural representation
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "format": {"class_name": "CodeableConcept", "is_contained": False},
        "attachment": {"class_name": "Attachment", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        representation: "str" = None,
        format: "CodeableConcept" = None,
        attachment: "Attachment" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.representation = representation
        self.format = format
        self.attachment = attachment

    @classmethod
    def from_dict(cls, data: dict) -> "SubstancePolymer":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstancePolymer":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class RepeatUnit(FhirBaseModel):
    """An SRU - Structural Repeat Unit.:param CodeableConcept repeatUnitAmountType: How the quantitative amount of Structural Repeat Units is captured (e.g. Exact, Numeric, Average)
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str unit: Structural repeat units are essential elements for defining polymers
    :param CodeableConcept orientation: The orientation of the polymerisation, e.g. head-tail, head-head, random
    :param int amount: Number of repeats of this unit
    :param DegreeOfPolymerisation degreeOfPolymerisation: Applies to homopolymer and block co-polymers where the degree of polymerisation within a block can be described
    :param StructuralRepresentation structuralRepresentation: A graphical structure for this SRU
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "repeatUnitAmountType": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "orientation": {"class_name": "CodeableConcept", "is_contained": False},
        "degreeOfPolymerisation": {
            "class_name": "DegreeOfPolymerisation",
            "is_contained": True,
        },
        "structuralRepresentation": {
            "class_name": "StructuralRepresentation",
            "is_contained": True,
        },
    }

    def __init__(
        self,
        repeatUnitAmountType: "CodeableConcept" = None,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        unit: "str" = None,
        orientation: "CodeableConcept" = None,
        amount: "int" = None,
        degreeOfPolymerisation: list["DegreeOfPolymerisation"] = None,
        structuralRepresentation: list["StructuralRepresentation"] = None,
    ):
        self.repeatUnitAmountType = repeatUnitAmountType
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.unit = unit
        self.orientation = orientation
        self.amount = amount
        self.degreeOfPolymerisation = degreeOfPolymerisation or []
        self.structuralRepresentation = structuralRepresentation or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstancePolymer":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstancePolymer":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Repeat(FhirBaseModel):
    """Specifies and quantifies the repeated units and their configuration.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str averageMolecularFormula: A representation of an (average) molecular formula from a polymer
    :param CodeableConcept repeatUnitAmountType: How the quantitative amount of Structural Repeat Units is captured (e.g. Exact, Numeric, Average)
    :param RepeatUnit repeatUnit: An SRU - Structural Repeat Unit
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "repeatUnitAmountType": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "repeatUnit": {"class_name": "RepeatUnit", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        averageMolecularFormula: "str" = None,
        repeatUnitAmountType: "CodeableConcept" = None,
        repeatUnit: list["RepeatUnit"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.averageMolecularFormula = averageMolecularFormula
        self.repeatUnitAmountType = repeatUnitAmountType
        self.repeatUnit = repeatUnit or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstancePolymer":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstancePolymer":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SubstancePolymer(DomainResource):
    """Properties of a substance specific to it being a polymer.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: A business idenfier for this polymer, but typically this is handled by a SubstanceDefinition identifier
    :param CodeableConcept _class: Overall type of the polymer
    :param CodeableConcept geometry: Polymer geometry, e.g. linear, branched, cross-linked, network or dendritic
    :param CodeableConcept copolymerConnectivity: Descrtibes the copolymer sequence type (polymer connectivity)
    :param str modification: Todo - this is intended to connect to a repeating full modification structure, also used by Protein and Nucleic Acid . String is just a placeholder
    :param MonomerSet monomerSet: Todo
    :param Repeat repeat: Specifies and quantifies the repeated units and their configuration
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "_class": {"class_name": "CodeableConcept", "is_contained": False},
        "geometry": {"class_name": "CodeableConcept", "is_contained": False},
        "copolymerConnectivity": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "monomerSet": {"class_name": "MonomerSet", "is_contained": True},
        "repeat": {"class_name": "Repeat", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: "Identifier" = None,
        _class: "CodeableConcept" = None,
        geometry: "CodeableConcept" = None,
        copolymerConnectivity: list["CodeableConcept"] = None,
        modification: "str" = None,
        monomerSet: list["MonomerSet"] = None,
        repeat: list["Repeat"] = None,
    ):

        self.resourceType = "SubstancePolymer"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier
        self._class = _class
        self.geometry = geometry
        self.copolymerConnectivity = copolymerConnectivity or []
        self.modification = modification
        self.monomerSet = monomerSet or []
        self.repeat = repeat or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstancePolymer":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstancePolymer":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for NutritionProduct. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Annotation import *
from fhirmodels.R4B.Attachment import *
from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.CodeableReference import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Ratio import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class Nutrient(FhirBaseModel):
    """The product's nutritional information expressed by the nutrients.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableReference item: The (relevant) nutrients in the product
    :param Ratio amount: The amount of nutrient expressed in one or more units: X per pack / per serving / per dose
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "item": {"class_name": "CodeableReference", "is_contained": False},
        "amount": {"class_name": "Ratio", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        item: "CodeableReference" = None,
        amount: list["Ratio"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.item = item
        self.amount = amount or []

    @classmethod
    def from_dict(cls, data: dict) -> "NutritionProduct":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "NutritionProduct":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Ingredient(FhirBaseModel):
    """Ingredients contained in this product.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableReference item: The ingredient contained in the product
    :param Ratio amount: The amount of ingredient that is in the product
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "item": {"class_name": "CodeableReference", "is_contained": False},
        "amount": {"class_name": "Ratio", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        item: "CodeableReference" = None,
        amount: list["Ratio"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.item = item
        self.amount = amount or []

    @classmethod
    def from_dict(cls, data: dict) -> "NutritionProduct":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "NutritionProduct":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ProductCharacteristic(FhirBaseModel):
    """Specifies descriptive properties of the nutrition product.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Code specifying the type of characteristic
    :param CodeableConcept valueCodeableConcept: The value of the characteristic
    :param str valueString: The value of the characteristic
    :param Quantity valueQuantity: The value of the characteristic
    :param str valueBase64Binary: The value of the characteristic
    :param Attachment valueAttachment: The value of the characteristic
    :param bool valueBoolean: The value of the characteristic
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueAttachment": {"class_name": "Attachment", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueString: "str" = None,
        valueQuantity: "Quantity" = None,
        valueBase64Binary: "str" = None,
        valueAttachment: "Attachment" = None,
        valueBoolean: "bool" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.valueCodeableConcept = valueCodeableConcept
        self.valueString = valueString
        self.valueQuantity = valueQuantity
        self.valueBase64Binary = valueBase64Binary
        self.valueAttachment = valueAttachment
        self.valueBoolean = valueBoolean

    @classmethod
    def from_dict(cls, data: dict) -> "NutritionProduct":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "NutritionProduct":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Instance(FhirBaseModel):
    """Conveys instance-level information about this product item. One or several physical, countable instances or occurrences of the product.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Quantity quantity: The amount of items or instances
    :param Identifier identifier: The identifier for the physical instance, typically a serial number
    :param str lotNumber: The identification of the batch or lot of the product
    :param str expiry: The expiry date or date and time for the product
    :param str useBy: The date until which the product is expected to be good for consumption
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        quantity: "Quantity" = None,
        identifier: list["Identifier"] = None,
        lotNumber: "str" = None,
        expiry: "str" = None,
        useBy: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.quantity = quantity
        self.identifier = identifier or []
        self.lotNumber = lotNumber
        self.expiry = expiry
        self.useBy = useBy

    @classmethod
    def from_dict(cls, data: dict) -> "NutritionProduct":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "NutritionProduct":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class NutritionProduct(DomainResource):
    """A food or fluid product that is consumed by patients.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str status: active | inactive | entered-in-error
    :param CodeableConcept category: A category or class of the nutrition product (halal, kosher, gluten free, vegan, etc)
    :param CodeableConcept code: A code designating a specific type of nutritional product
    :param Reference manufacturer: Manufacturer, representative or officially responsible for the product
    :param Nutrient nutrient: The product's nutritional information expressed by the nutrients
    :param Ingredient ingredient: Ingredients contained in this product
    :param CodeableReference knownAllergen: Known or suspected allergens that are a part of this product
    :param ProductCharacteristic productCharacteristic: Specifies descriptive properties of the nutrition product
    :param Instance instance: One or several physical instances or occurrences of the nutrition product
    :param Annotation note: Comments made about the product
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "manufacturer": {"class_name": "Reference", "is_contained": False},
        "nutrient": {"class_name": "Nutrient", "is_contained": True},
        "ingredient": {"class_name": "Ingredient", "is_contained": True},
        "knownAllergen": {"class_name": "CodeableReference", "is_contained": False},
        "productCharacteristic": {
            "class_name": "ProductCharacteristic",
            "is_contained": True,
        },
        "instance": {"class_name": "Instance", "is_contained": True},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        status: "str" = None,
        category: list["CodeableConcept"] = None,
        code: "CodeableConcept" = None,
        manufacturer: list["Reference"] = None,
        nutrient: list["Nutrient"] = None,
        ingredient: list["Ingredient"] = None,
        knownAllergen: list["CodeableReference"] = None,
        productCharacteristic: list["ProductCharacteristic"] = None,
        instance: "Instance" = None,
        note: list["Annotation"] = None,
    ):

        self.resourceType = "NutritionProduct"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.status = status
        self.category = category or []
        self.code = code
        self.manufacturer = manufacturer or []
        self.nutrient = nutrient or []
        self.ingredient = ingredient or []
        self.knownAllergen = knownAllergen or []
        self.productCharacteristic = productCharacteristic or []
        self.instance = instance
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "NutritionProduct":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "NutritionProduct":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for TestScript. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.Coding import *
from fhirmodels.R5.ContactDetail import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.UsageContext import *


class Origin(FhirBaseModel):
    """An abstract server used in operations within this test script in the origin element.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int index: The index of the abstract origin server starting at 1
    :param Coding profile: FHIR-Client | FHIR-SDC-FormFiller
    :param str url: The url path of the origin server
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "profile": {"class_name": "Coding", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        index: "int" = None,
        profile: "Coding" = None,
        url: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.index = index
        self.profile = profile
        self.url = url

    @classmethod
    def from_dict(cls, data: dict) -> "TestScript":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestScript":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Destination(FhirBaseModel):
    """An abstract server used in operations within this test script in the destination element.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int index: The index of the abstract destination server starting at 1
    :param Coding profile: FHIR-Server | FHIR-SDC-FormManager | FHIR-SDC-FormReceiver | FHIR-SDC-FormProcessor
    :param str url: The url path of the destination server
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "profile": {"class_name": "Coding", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        index: "int" = None,
        profile: "Coding" = None,
        url: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.index = index
        self.profile = profile
        self.url = url

    @classmethod
    def from_dict(cls, data: dict) -> "TestScript":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestScript":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Link(FhirBaseModel):
    """A link to the FHIR specification that this test is covering.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str url: URL to the specification
    :param str description: Short description
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        description: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.description = description

    @classmethod
    def from_dict(cls, data: dict) -> "TestScript":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestScript":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Capability(FhirBaseModel):
    """Capabilities that must exist and are assumed to function correctly on the FHIR server being tested.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param bool required: Are the capabilities required?
    :param bool validated: Are the capabilities validated?
    :param str description: The expected capabilities of the server
    :param int origin: Which origin server these requirements apply to
    :param int destination: Which server these requirements apply to
    :param str link: Links to the FHIR specification
    :param str capabilities: Required Capability Statement
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        required: "bool" = None,
        validated: "bool" = None,
        description: "str" = None,
        origin: list["int"] = None,
        destination: "int" = None,
        link: list["str"] = None,
        capabilities: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.required = required
        self.validated = validated
        self.description = description
        self.origin = origin or []
        self.destination = destination
        self.link = link or []
        self.capabilities = capabilities

    @classmethod
    def from_dict(cls, data: dict) -> "TestScript":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestScript":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Metadata(FhirBaseModel):
    """The required capability must exist and are assumed to function correctly on the FHIR server being tested.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Link link: Links to the FHIR specification
    :param Capability capability: Capabilities  that are assumed to function correctly on the FHIR server being tested
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "link": {"class_name": "Link", "is_contained": True},
        "capability": {"class_name": "Capability", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        link: list["Link"] = None,
        capability: list["Capability"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.link = link or []
        self.capability = capability or []

    @classmethod
    def from_dict(cls, data: dict) -> "TestScript":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestScript":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Scope(FhirBaseModel):
    """The scope indicates a conformance artifact that is tested by the test(s) within this test case and the expectation of the test outcome(s) as well as the intended test phase inclusion.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str artifact: The specific conformance artifact being tested
    :param CodeableConcept conformance: required | optional | strict
    :param CodeableConcept phase: unit | integration | production
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "conformance": {"class_name": "CodeableConcept", "is_contained": False},
        "phase": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        artifact: "str" = None,
        conformance: "CodeableConcept" = None,
        phase: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.artifact = artifact
        self.conformance = conformance
        self.phase = phase

    @classmethod
    def from_dict(cls, data: dict) -> "TestScript":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestScript":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Fixture(FhirBaseModel):
    """Fixture in the test script - by reference (uri). All fixtures are required for the test script to execute.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param bool autocreate: Whether or not to implicitly create the fixture during setup
    :param bool autodelete: Whether or not to implicitly delete the fixture during teardown
    :param Reference resource: Reference of the resource
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "resource": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        autocreate: "bool" = None,
        autodelete: "bool" = None,
        resource: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.autocreate = autocreate
        self.autodelete = autodelete
        self.resource = resource

    @classmethod
    def from_dict(cls, data: dict) -> "TestScript":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestScript":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Variable(FhirBaseModel):
    """Variable is set based either on element value in response body or on header field value in the response headers.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str name: Descriptive name for this variable
    :param str defaultValue: Default, hard-coded, or user-defined value for this variable
    :param str description: Natural language description of the variable
    :param str expression: The FHIRPath expression against the fixture body
    :param str headerField: HTTP header field name for source
    :param str hint: Hint help text for default value to enter
    :param str path: XPath or JSONPath against the fixture body
    :param str sourceId: Fixture Id of source expression or headerField within this variable
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        name: "str" = None,
        defaultValue: "str" = None,
        description: "str" = None,
        expression: "str" = None,
        headerField: "str" = None,
        hint: "str" = None,
        path: "str" = None,
        sourceId: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.name = name
        self.defaultValue = defaultValue
        self.description = description
        self.expression = expression
        self.headerField = headerField
        self.hint = hint
        self.path = path
        self.sourceId = sourceId

    @classmethod
    def from_dict(cls, data: dict) -> "TestScript":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestScript":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class RequestHeader(FhirBaseModel):
    """Header elements would be used to set HTTP headers.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str field: HTTP header field name
    :param str value: HTTP headerfield value
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        field: "str" = None,
        value: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.field = field
        self.value = value

    @classmethod
    def from_dict(cls, data: dict) -> "TestScript":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestScript":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Operation(FhirBaseModel):
    """The operation to perform.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Coding type: The operation code type that will be executed
    :param str resource: Resource type
    :param str label: Tracking/logging operation label
    :param str description: Tracking/reporting operation description
    :param str accept: Mime type to accept in the payload of the response, with charset etc
    :param str contentType: Mime type of the request payload contents, with charset etc
    :param int destination: Server responding to the request
    :param bool encodeRequestUrl: Whether or not to send the request url in encoded format
    :param str method: delete | get | options | patch | post | put | head
    :param int origin: Server initiating the request
    :param str params: Explicitly defined path parameters
    :param RequestHeader requestHeader: Each operation can have one or more header elements
    :param str requestId: Fixture Id of mapped request
    :param str responseId: Fixture Id of mapped response
    :param str sourceId: Fixture Id of body for PUT and POST requests
    :param str targetId: Id of fixture used for extracting the [id],  [type], and [vid] for GET requests
    :param str url: Request URL
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "Coding", "is_contained": False},
        "requestHeader": {"class_name": "RequestHeader", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "Coding" = None,
        resource: "str" = None,
        label: "str" = None,
        description: "str" = None,
        accept: "str" = None,
        contentType: "str" = None,
        destination: "int" = None,
        encodeRequestUrl: "bool" = None,
        method: "str" = None,
        origin: "int" = None,
        params: "str" = None,
        requestHeader: list["RequestHeader"] = None,
        requestId: "str" = None,
        responseId: "str" = None,
        sourceId: "str" = None,
        targetId: "str" = None,
        url: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.resource = resource
        self.label = label
        self.description = description
        self.accept = accept
        self.contentType = contentType
        self.destination = destination
        self.encodeRequestUrl = encodeRequestUrl
        self.method = method
        self.origin = origin
        self.params = params
        self.requestHeader = requestHeader or []
        self.requestId = requestId
        self.responseId = responseId
        self.sourceId = sourceId
        self.targetId = targetId
        self.url = url

    @classmethod
    def from_dict(cls, data: dict) -> "TestScript":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestScript":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Requirement(FhirBaseModel):
    """Links or references providing traceability to the testing requirements for this assert.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str linkUri: Link or reference to the testing requirement
    :param str linkCanonical: Link or reference to the testing requirement
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        linkUri: "str" = None,
        linkCanonical: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.linkUri = linkUri
        self.linkCanonical = linkCanonical

    @classmethod
    def from_dict(cls, data: dict) -> "TestScript":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestScript":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class _assert(FhirBaseModel):
    """Evaluates the results of previous operations to determine if the server under test behaves appropriately.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str label: Tracking/logging assertion label
    :param str description: Tracking/reporting assertion description
    :param str direction: response | request
    :param str compareToSourceId: Id of the source fixture to be evaluated
    :param str compareToSourceExpression: The FHIRPath expression to evaluate against the source fixture
    :param str compareToSourcePath: XPath or JSONPath expression to evaluate against the source fixture
    :param str contentType: Mime type to compare against the 'Content-Type' header
    :param str defaultManualCompletion: fail | pass | skip | stop
    :param str expression: The FHIRPath expression to be evaluated
    :param str headerField: HTTP header field name
    :param str minimumId: Fixture Id of minimum content resource
    :param bool navigationLinks: Perform validation on navigation links?
    :param str operator: equals | notEquals | in | notIn | greaterThan | lessThan | empty | notEmpty | contains | notContains | eval | manualEval
    :param str path: XPath or JSONPath expression
    :param str requestMethod: delete | get | options | patch | post | put | head
    :param str requestURL: Request URL comparison value
    :param str resource: Resource type
    :param str response: continue | switchingProtocols | okay | created | accepted | nonAuthoritativeInformation | noContent | resetContent | partialContent | multipleChoices | movedPermanently | found | seeOther | notModified | useProxy | temporaryRedirect | permanentRedirect | badRequest | unauthorized | paymentRequired | forbidden | notFound | methodNotAllowed | notAcceptable | proxyAuthenticationRequired | requestTimeout | conflict | gone | lengthRequired | preconditionFailed | contentTooLarge | uriTooLong | unsupportedMediaType | rangeNotSatisfiable | expectationFailed | misdirectedRequest | unprocessableContent | upgradeRequired | internalServerError | notImplemented | badGateway | serviceUnavailable | gatewayTimeout | httpVersionNotSupported
    :param str responseCode: HTTP response code to test
    :param str sourceId: Fixture Id of source expression or headerField
    :param bool stopTestOnFail: If this assert fails, will the current test execution stop?
    :param str validateProfileId: Profile Id of validation profile reference
    :param str value: The value to compare to
    :param bool warningOnly: Will this assert produce a warning only on error?
    :param Requirement requirement: Links or references to the testing requirements
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "requirement": {"class_name": "Requirement", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        label: "str" = None,
        description: "str" = None,
        direction: "str" = None,
        compareToSourceId: "str" = None,
        compareToSourceExpression: "str" = None,
        compareToSourcePath: "str" = None,
        contentType: "str" = None,
        defaultManualCompletion: "str" = None,
        expression: "str" = None,
        headerField: "str" = None,
        minimumId: "str" = None,
        navigationLinks: "bool" = None,
        operator: "str" = None,
        path: "str" = None,
        requestMethod: "str" = None,
        requestURL: "str" = None,
        resource: "str" = None,
        response: "str" = None,
        responseCode: "str" = None,
        sourceId: "str" = None,
        stopTestOnFail: "bool" = None,
        validateProfileId: "str" = None,
        value: "str" = None,
        warningOnly: "bool" = None,
        requirement: list["Requirement"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.label = label
        self.description = description
        self.direction = direction
        self.compareToSourceId = compareToSourceId
        self.compareToSourceExpression = compareToSourceExpression
        self.compareToSourcePath = compareToSourcePath
        self.contentType = contentType
        self.defaultManualCompletion = defaultManualCompletion
        self.expression = expression
        self.headerField = headerField
        self.minimumId = minimumId
        self.navigationLinks = navigationLinks
        self.operator = operator
        self.path = path
        self.requestMethod = requestMethod
        self.requestURL = requestURL
        self.resource = resource
        self.response = response
        self.responseCode = responseCode
        self.sourceId = sourceId
        self.stopTestOnFail = stopTestOnFail
        self.validateProfileId = validateProfileId
        self.value = value
        self.warningOnly = warningOnly
        self.requirement = requirement or []

    @classmethod
    def from_dict(cls, data: dict) -> "TestScript":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestScript":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Action(FhirBaseModel):
    """Action would contain either an operation or an assertion.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Operation operation: The setup operation to perform
    :param _assert _assert: The assertion to perform
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "operation": {"class_name": "Operation", "is_contained": True},
        "_assert": {"class_name": "_assert", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        operation: "Operation" = None,
        _assert: "_assert" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.operation = operation
        self._assert = _assert

    @classmethod
    def from_dict(cls, data: dict) -> "TestScript":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestScript":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Setup(FhirBaseModel):
    """A series of required setup operations before tests are executed.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Action action: A setup operation or assert to perform
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "action": {"class_name": "Action", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        action: list["Action"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.action = action or []

    @classmethod
    def from_dict(cls, data: dict) -> "TestScript":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestScript":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Action(FhirBaseModel):
    """Action would contain either an operation or an assertion.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Operation operation: The setup operation to perform
    :param _assert _assert: The setup assertion to perform
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "operation": {"class_name": "Operation", "is_contained": True},
        "_assert": {"class_name": "_assert", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        operation: "Operation" = None,
        _assert: "_assert" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.operation = operation
        self._assert = _assert

    @classmethod
    def from_dict(cls, data: dict) -> "TestScript":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestScript":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Test(FhirBaseModel):
    """A test in this script.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str name: Tracking/logging name of this test
    :param str description: Tracking/reporting short description of the test
    :param Action action: A test operation or assert to perform
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "action": {"class_name": "Action", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        name: "str" = None,
        description: "str" = None,
        action: list["Action"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.name = name
        self.description = description
        self.action = action or []

    @classmethod
    def from_dict(cls, data: dict) -> "TestScript":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestScript":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Action(FhirBaseModel):
    """The teardown action will only contain an operation.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Operation operation: The teardown operation to perform
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "operation": {"class_name": "Operation", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        operation: "Operation" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.operation = operation

    @classmethod
    def from_dict(cls, data: dict) -> "TestScript":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestScript":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Teardown(FhirBaseModel):
    """A series of operations required to clean up after all the tests are executed (successfully or otherwise).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Action action: One or more teardown operations to perform
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "action": {"class_name": "Action", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        action: list["Action"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.action = action or []

    @classmethod
    def from_dict(cls, data: dict) -> "TestScript":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestScript":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class TestScript(DomainResource):
    """A structured set of tests against a FHIR server or client implementation to determine compliance against the FHIR specification.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this test script, represented as a URI (globally unique)
    :param Identifier identifier: Additional identifier for the test script
    :param str version: Business version of the test script
    :param str versionAlgorithmString: How to compare versions
    :param Coding versionAlgorithmCoding: How to compare versions
    :param str name: Name for this test script (computer friendly)
    :param str title: Name for this test script (human friendly)
    :param str status: draft | active | retired | unknown
    :param bool experimental: For testing purposes, not real usage
    :param str date: Date last changed
    :param str publisher: Name of the publisher/steward (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the test script
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for test script (if applicable)
    :param str purpose: Why this test script is defined
    :param str copyright: Use and/or publishing restrictions
    :param str copyrightLabel: Copyright holder and year(s)
    :param Origin origin: An abstract server representing a client or sender in a message exchange
    :param Destination destination: An abstract server representing a destination or receiver in a message exchange
    :param Metadata metadata: Required capability that is assumed to function correctly on the FHIR server being tested
    :param Scope scope: Indication of the artifact(s) that are tested by this test case
    :param Fixture fixture: Fixture in the test script - by reference (uri)
    :param str profile: Reference of the validation profile
    :param Variable variable: Placeholder for evaluated elements
    :param Setup setup: A series of required setup operations before tests are executed
    :param Test test: A test in this script
    :param Teardown teardown: A series of required clean up steps
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "versionAlgorithmCoding": {"class_name": "Coding", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "origin": {"class_name": "Origin", "is_contained": True},
        "destination": {"class_name": "Destination", "is_contained": True},
        "metadata": {"class_name": "Metadata", "is_contained": True},
        "scope": {"class_name": "Scope", "is_contained": True},
        "fixture": {"class_name": "Fixture", "is_contained": True},
        "variable": {"class_name": "Variable", "is_contained": True},
        "setup": {"class_name": "Setup", "is_contained": True},
        "test": {"class_name": "Test", "is_contained": True},
        "teardown": {"class_name": "Teardown", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        versionAlgorithmString: "str" = None,
        versionAlgorithmCoding: "Coding" = None,
        name: "str" = None,
        title: "str" = None,
        status: "str" = None,
        experimental: "bool" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        purpose: "str" = None,
        copyright: "str" = None,
        copyrightLabel: "str" = None,
        origin: list["Origin"] = None,
        destination: list["Destination"] = None,
        metadata: "Metadata" = None,
        scope: list["Scope"] = None,
        fixture: list["Fixture"] = None,
        profile: list["str"] = None,
        variable: list["Variable"] = None,
        setup: "Setup" = None,
        test: list["Test"] = None,
        teardown: "Teardown" = None,
    ):

        self.resourceType = "TestScript"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.versionAlgorithmString = versionAlgorithmString
        self.versionAlgorithmCoding = versionAlgorithmCoding
        self.name = name
        self.title = title
        self.status = status
        self.experimental = experimental
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.purpose = purpose
        self.copyright = copyright
        self.copyrightLabel = copyrightLabel
        self.origin = origin or []
        self.destination = destination or []
        self.metadata = metadata
        self.scope = scope or []
        self.fixture = fixture or []
        self.profile = profile or []
        self.variable = variable or []
        self.setup = setup
        self.test = test or []
        self.teardown = teardown

    @classmethod
    def from_dict(cls, data: dict) -> "TestScript":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestScript":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MessageDefinition. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.Coding import *
from fhirmodels.R4B.ContactDetail import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Resource import *
from fhirmodels.R4B.UsageContext import *


class Focus(FhirBaseModel):
    """Identifies the resource (or resources) that are being addressed by the event.  For example, the Encounter for an admit message or two Account records for a merge.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str code: Type of resource
    :param str profile: Profile that must be adhered to by focus
    :param int min: Minimum number of focuses of this type
    :param str max: Maximum number of focuses of this type
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "str" = None,
        profile: "str" = None,
        min: "int" = None,
        max: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.profile = profile
        self.min = min
        self.max = max

    @classmethod
    def from_dict(cls, data: dict) -> "MessageDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MessageDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class AllowedResponse(FhirBaseModel):
    """Indicates what types of messages may be sent as an application-level response to this message.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str message: Reference to allowed message definition response
    :param str situation: When should this response be used
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        message: "str" = None,
        situation: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.message = message
        self.situation = situation

    @classmethod
    def from_dict(cls, data: dict) -> "MessageDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MessageDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MessageDefinition(DomainResource):
    """Defines the characteristics of a message that can be shared between systems, including the type of event that initiates the message, the content to be transmitted and what response(s), if any, are permitted.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Business Identifier for a given MessageDefinition
    :param Identifier identifier: Primary key for the message definition on a given server
    :param str version: Business version of the message definition
    :param str name: Name for this message definition (computer friendly)
    :param str title: Name for this message definition (human friendly)
    :param str replaces: Takes the place of
    :param str status: draft | active | retired | unknown
    :param bool experimental: For testing purposes, not real usage
    :param str date: Date last changed
    :param str publisher: Name of the publisher (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the message definition
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for message definition (if applicable)
    :param str purpose: Why this message definition is defined
    :param str copyright: Use and/or publishing restrictions
    :param str base: Definition this one is based on
    :param str parent: Protocol/workflow this is part of
    :param Coding eventCoding: Event code  or link to the EventDefinition
    :param str eventUri: Event code  or link to the EventDefinition
    :param str category: consequence | currency | notification
    :param Focus focus: Resource(s) that are the subject of the event
    :param str responseRequired: always | on-error | never | on-success
    :param AllowedResponse allowedResponse: Responses to this message
    :param str graph: Canonical reference to a GraphDefinition
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "eventCoding": {"class_name": "Coding", "is_contained": False},
        "focus": {"class_name": "Focus", "is_contained": True},
        "allowedResponse": {"class_name": "AllowedResponse", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        name: "str" = None,
        title: "str" = None,
        replaces: list["str"] = None,
        status: "str" = None,
        experimental: "bool" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        purpose: "str" = None,
        copyright: "str" = None,
        base: "str" = None,
        parent: list["str"] = None,
        eventCoding: "Coding" = None,
        eventUri: "str" = None,
        category: "str" = None,
        focus: list["Focus"] = None,
        responseRequired: "str" = None,
        allowedResponse: list["AllowedResponse"] = None,
        graph: list["str"] = None,
    ):

        self.resourceType = "MessageDefinition"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.name = name
        self.title = title
        self.replaces = replaces or []
        self.status = status
        self.experimental = experimental
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.purpose = purpose
        self.copyright = copyright
        self.base = base
        self.parent = parent or []
        self.eventCoding = eventCoding
        self.eventUri = eventUri
        self.category = category
        self.focus = focus or []
        self.responseRequired = responseRequired
        self.allowedResponse = allowedResponse or []
        self.graph = graph or []

    @classmethod
    def from_dict(cls, data: dict) -> "MessageDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MessageDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ManufacturedItemDefinition. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Attachment import *
from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class Property(FhirBaseModel):
    """General characteristics of this item.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: A code expressing the type of characteristic
    :param CodeableConcept valueCodeableConcept: A value for the characteristic
    :param Quantity valueQuantity: A value for the characteristic
    :param str valueDate: A value for the characteristic
    :param bool valueBoolean: A value for the characteristic
    :param Attachment valueAttachment: A value for the characteristic
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueAttachment": {"class_name": "Attachment", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueQuantity: "Quantity" = None,
        valueDate: "str" = None,
        valueBoolean: "bool" = None,
        valueAttachment: "Attachment" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.valueCodeableConcept = valueCodeableConcept
        self.valueQuantity = valueQuantity
        self.valueDate = valueDate
        self.valueBoolean = valueBoolean
        self.valueAttachment = valueAttachment

    @classmethod
    def from_dict(cls, data: dict) -> "ManufacturedItemDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ManufacturedItemDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ManufacturedItemDefinition(DomainResource):
    """The definition and characteristics of a medicinal manufactured item, such as a tablet or capsule, as contained in a packaged medicinal product.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Unique identifier
    :param str status: draft | active | retired | unknown
    :param CodeableConcept manufacturedDoseForm: Dose form as manufactured (before any necessary transformation)
    :param CodeableConcept unitOfPresentation: The “real world” units in which the quantity of the item is described
    :param Reference manufacturer: Manufacturer of the item (Note that this should be named "manufacturer" but it currently causes technical issues)
    :param CodeableConcept ingredient: The ingredients of this manufactured item. Only needed if these are not specified by incoming references from the Ingredient resource
    :param Property property: General characteristics of this item
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "manufacturedDoseForm": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "unitOfPresentation": {"class_name": "CodeableConcept", "is_contained": False},
        "manufacturer": {"class_name": "Reference", "is_contained": False},
        "ingredient": {"class_name": "CodeableConcept", "is_contained": False},
        "property": {"class_name": "Property", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        manufacturedDoseForm: "CodeableConcept" = None,
        unitOfPresentation: "CodeableConcept" = None,
        manufacturer: list["Reference"] = None,
        ingredient: list["CodeableConcept"] = None,
        property: list["Property"] = None,
    ):

        self.resourceType = "ManufacturedItemDefinition"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.manufacturedDoseForm = manufacturedDoseForm
        self.unitOfPresentation = unitOfPresentation
        self.manufacturer = manufacturer or []
        self.ingredient = ingredient or []
        self.property = property or []

    @classmethod
    def from_dict(cls, data: dict) -> "ManufacturedItemDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ManufacturedItemDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()
